{ config
, lib
, pkgs
, ...
}: {
  programs.dconf.enable = true;

  fonts = {
    enableDefaultPackages = true;
    fontDir.enable = true;
    fontconfig = {
      antialias = true;

      defaultFonts.serif = [ "Iosevka Nerd Font Propo" ];
      defaultFonts.sansSerif = [ "Iosevka Nerd Font Propo" ];
      defaultFonts.monospace = [ "Iosevka Nerd Font Mono" ];
      defaultFonts.emoji = [ "Noto Color Emoji" ];

      hinting.enable = true;
      hinting.style = "slight";

      subpixel.rgba = lib.mkDefault "rgb";
      subpixel.lcdfilter = "default";
    };
    packages = with pkgs; [
      emacs-all-the-icons-fonts
      corefonts
      vistafonts
      noto-fonts
      noto-fonts-cjk
      noto-fonts-emoji
      liberation_ttf
      fira
      fira-code
      fira-code-symbols
      mplus-outline-fonts.githubRelease
      dina-font
      proggyfonts
      (nerdfonts.override {
        fonts = [ "Iosevka" "IosevkaTerm" "FiraCode" "DroidSansMono" "NerdFontsSymbolsOnly" ];
      })
    ];
  };

  networking.firewall = {
    enable = true;
    allowedTCPPortRanges = [
      {
        from = 1714;
        to = 1764;
      } # KDE Connect
    ];
    allowedUDPPortRanges = [
      {
        from = 1714;
        to = 1764;
      } # KDE Connect
    ];
  };

  services = {
    xserver = {
      enable = true;
      layout = "us";
      xkbVariant = "alt-intl";

      desktopManager.plasma5.enable = true;

      displayManager = {
        defaultSession = "plasmawayland";

        sddm.enable = true;

        # autoLogin = {
        #  enable = true;
        #  user = "tristand";
        # };
      };
    };
  };
}
