{ config
, lib
, pkgs
, modulesPath
, system
, inputs
, ...
}: {
  imports = [
    (modulesPath + "/installer/scan/not-detected.nix")
    ../../os-mods/amdgpu
    ../../os-mods/cachix
    ../../os-mods/common
    ../../os-mods/desktop
    ../../os-mods/desktop/audio.nix
    ../../os-mods/desktop/gaming.nix
    ../../os-mods/desktop/printing.nix
    # ../../os-mods/mac-vm
    ../../os-mods/netdata
    ../../os-mods/network
    ../../os-mods/virt
    ../../os-mods/xmr
    ../../users
    ./disko.nix
  ];

  config = {
    system.stateVersion = "23.05";

    nix.settings.system-features = [
      "benchmark"
      "big-parallel"
      "kvm"
      "nixos-test"
      "gccarch-x86-64-v3"
      "gccarch-znver3"
    ];
    boot = {
      kernelPackages = pkgs.pkgsx86_64_v3.linuxPackages_cachyos;
      loader = {
        systemd-boot = {
          enable = true;
          configurationLimit = 32;
        };
        efi.canTouchEfiVariables = true;
      };

      initrd = {
        availableKernelModules = [ "ahci" "nvme" "xhci_pci" "uas" "usbhid" "usb_storage" "sd_mod" ];
        kernelModules = [ ];
        systemd.enable = true;
      };

      kernelModules = [ "kvm-amd" ];
      extraModulePackages = [ ];
    };

    services.btrfs.autoScrub.enable = true;

    networking = {
      hostName = "nixos-desk";
      useDHCP = lib.mkDefault true;
    };

    hardware = {
      cpu.amd.updateMicrocode = lib.mkDefault config.hardware.enableRedistributableFirmware;
    };

    zramSwap.enable = true;
  };
}
